@@ -299,10 +299,7 @@ void MainWindow::newConnection(const QUrl &newUrl, bool switchFullscreenWhenConn
 
     // Configure the view
     HostPreferences* prefs = view->hostPreferences();
-    if (! prefs->showDialogIfNeeded(this)) {
-        delete view;
-        return;
-    }
+    prefs->showDialogIfNeeded(this);
 
     view->showDotCursor(prefs->showLocalCursor() ? RemoteView::CursorOn : RemoteView::CursorOff);
     view->setViewOnly(prefs->viewOnly());
@@ -989,7 +986,6 @@ void MainWindow::saveHostPrefs()
 {
     foreach (RemoteView *view, m_remoteViewMap.values()) {
         saveHostPrefs(view);
-        view->startQuitting();
     }
 }
 
